==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: it\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "Tabella del tempo"
 ,"Schede attività"

]
, "Account"
: "Account"

, "Time Account (Number - Title)"
: "Rendiconto Ore (Numero - Titolo)"

, "Billable"
: "Fatturabile"

, "Cleared in"
: "Approvato"

, "Invoice"
: ""

, "Cleared"
: "Approvata"

, "Date"
: "Data"

, "Start time"
: "Data inizio"

, "End time"
: ""

, "Duration"
: "Durata"

, "Description"
: "Descrizione"

, "Type"
: ""

, "Time Account closed"
: "Rendiconto Ore chiuso"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Contract"
: "Contratto"

, "Title"
: "Titolo"

, "Number"
: "Numero"

, "Price"
: ""

, "Status"
: "Stato"

, "Billed"
: "Fatturata"

, "Cleared at"
: "Approvata in data"

, "Booking deadline"
: "Scadenza prenotazione"

, "Responsible"
: ""

, "Cost Center"
: "Centro di costo"

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "Account di Tempo"
 ,"Rendiconti Ore"

]
, "Time Account - Status"
: "Rendiconto Ore - Stato"

, "closed"
: "chiuso"

, "open"
: "aperto"

, "Not a valid time"
: "Non è un tempo valido"

, "Time Account - Billed"
: "Rendiconto Ore - Fatturato"

, "not yet billed"
: "non ancora fatturata"

, "to bill"
: "da fatturare"

, "billed"
: "fatturata"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: "Approvato"

, "Select Time Account..."
: "Scegli Rendiconto Ore..."

, "Start"
: "Inizio"

, "not set"
: "non impostato"

, "End"
: ""

, "Enter description..."
: "Inserisci descrizione..."

, "Need for Clarification"
: ""

, "Failed"
: "Fallita"

, "Could not save {0}."
: "Impossibile salvare {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "La scadenza di prenotazione per questo rendiconto ore è stata superata"

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Prenota il proprio"

, "The grant to add Timesheets to this Timeaccount"
: "Il permesso di aggiungere delle Schede attività a questo Rendiconto ore"

, "View All"
: "Visualizza Tutti"

, "The grant to view Timesheets of other users"
: "Il permesso di visualizzare le schede attività degli altri utenti"

, "Book All"
: "Prenota Tutti"

, "The grant to add Timesheets for other users"
: "Il permesso di aggiungere delle schede attività per altri utenti"

, "Manage Clearing"
: "Gestisci approvazioni"

, "The grant to manage clearing of Timesheets"
: "Il permesso di gestire le approvazioni delle schede attività"

, "without contract"
: "senza contratto"

, "without responsible"
: ""

, "timeframe"
: "instante di tempo"

, "summary"
: "sommario"

, "Total Timesheets"
: "Totale Schede attività"

, "Billable Timesheets"
: "Schede attività fatturabili"

, "Total Time"
: "Tempo Totale"

, "Time of Billable Timesheets"
: "Tempo delle schede attività fatturabili"

, "Detail"
: "Dettaglio"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Esporta Schede attività"

, "Export as ODS"
: "Esporta come ODS"

, "Export as CSV"
: "Esporta come CSV"

, "Export as ..."
: "Esporta come ..."

, "Add New Timeaccount"
: ""

, "Unit"
: "Unità"

, "Unit Price"
: "Prezzo unitario"

, "Budget"
: "Budget"

, "Timesheets are billable"
: "Le schede attività sono fatturabili"

, "Access"
: "Accesso"

, "Permissions"
: "Permessi"

, "Show closed"
: "Mostra completati"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "Configurazione esportazione schede attività ODS"

, "Use this configuration for the timesheet ODS export."
: "Usa questa configurazione per l'esportazione delle schede attività ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "default"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "nessuno"

, "last week"
: "la scorsa settimana"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Gestisci rendiconto ore"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Aggiungere, modificare ed eliminare i rendiconto ore (include tutte i permessi della scheda attività)"

, "Add timeaccounts"
: "Aggiungi rendiconto ore"

, "Manage shared timeaccount favorites"
: "Gestisci i rendiconto ore condivisi preferiti"

, "Create or update shared timeaccount favorites"
: "Crea o aggiorna i rendiconto ore condivisi preferiti"

, "Manage shared timesheet favorites"
: "gestisci le schede attività condivise preferite"

, "Create or update shared timesheet favorites"
: "Crea o aggiorna le schede attività condivise preferite"

, "My Timesheets today"
: "La mia schede attività di oggi"

, "My Timesheets this week"
: "La mia scheda attività di questa settimana"

, "My Timesheets last week"
: "La mia scheda attività della scorsa settimana"

, "My Timesheets this month"
: "La mia scheda attività di questo mese"

, "My Timesheets last month"
: "La mia scheda attività dello scorso mese"

, "Timeaccounts to bill"
: "Rendiconto ore da fatturare"

, "Timeaccounts not yet billed"
: "Rendiconto ore non ancora fatturati"

, "Timeaccounts already billed"
: "Rendiconto ore già fatturati"

, "Timetracker"
: "Indicatore del tempo"

, "Timesheet"
: "Tabella del tempo"

, "Timeaccount"
: ""

, "Time Account"
: "Account di Tempo"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "instante di tempo"

, "summary"
: "sommario"

, "Total Timesheets"
: "Totale Schede attività"

, "Billable Timesheets"
: "Schede attività fatturabili"

, "Total Time"
: "Tempo Totale"

, "Time of Billable Timesheets"
: "Tempo delle schede attività fatturabili"

, "Description"
: "Descrizione"

, "Detail"
: "Dettaglio"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Esporta Schede attività"

, "Export as ODS"
: "Esporta come ODS"

, "Export as CSV"
: "Esporta come CSV"

, "Export as ..."
: "Esporta come ..."

, "Timesheet, Timesheets"
: [
  "Tabella del tempo"
 ,"Schede attività"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Fallita"

, "Could not save {0}."
: "Impossibile salvare {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "La scadenza di prenotazione per questo rendiconto ore è stata superata"

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Contratto"

, "without contract"
: "senza contratto"

, "Add New Timeaccount"
: ""

, "Unit"
: "Unità"

, "Unit Price"
: "Prezzo unitario"

, "Factor"
: ""

, "Budget"
: "Budget"

, "Status"
: "Stato"

, "closed"
: "chiuso"

, "open"
: "aperto"

, "Cleared In"
: "Approvato"

, "Cleared at"
: "Approvata in data"

, "Cost Center"
: "Centro di costo"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Le schede attività sono fatturabili"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Account di Tempo"
 ,"Rendiconti Ore"

]
, "Number"
: "Numero"

, "Title"
: "Titolo"

, "Access"
: "Accesso"

, "Permissions"
: "Permessi"

, "Time Account - Billed"
: "Rendiconto Ore - Fatturato"

, "not yet billed"
: "non ancora fatturata"

, "to bill"
: "da fatturare"

, "billed"
: "fatturata"

, "Time Account - Status"
: "Rendiconto Ore - Stato"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Prenota il proprio"

, "The grant to add Timesheets to this Timeaccount"
: "Il permesso di aggiungere delle Schede attività a questo Rendiconto ore"

, "View All"
: "Visualizza Tutti"

, "The grant to view Timesheets of other users"
: "Il permesso di visualizzare le schede attività degli altri utenti"

, "Book All"
: "Prenota Tutti"

, "The grant to add Timesheets for other users"
: "Il permesso di aggiungere delle schede attività per altri utenti"

, "Manage Clearing"
: "Gestisci approvazioni"

, "The grant to manage clearing of Timesheets"
: "Il permesso di gestire le approvazioni delle schede attività"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Mostra completati"

, "Timesheets ODS export configuration"
: "Configurazione esportazione schede attività ODS"

, "Use this configuration for the timesheet ODS export."
: "Usa questa configurazione per l'esportazione delle schede attività ODS"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "default"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "nessuno"

, "last week"
: "la scorsa settimana"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Approvato"

, "Billed"
: "Fatturata"

, "Booking deadline"
: "Scadenza prenotazione"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Account"

, "Time Account (Number - Title)"
: "Rendiconto Ore (Numero - Titolo)"

, "Billable"
: "Fatturabile"

, "Cleared"
: "Approvata"

, "Date"
: "Data"

, "Start time"
: "Data inizio"

, "End time"
: ""

, "Duration"
: "Durata"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Rendiconto Ore chiuso"

, "Timetracker"
: "Indicatore del tempo"

, "Timeaccounts to bill"
: "Rendiconto ore da fatturare"

, "Timeaccounts not yet billed"
: "Rendiconto ore non ancora fatturati"

, "Timeaccounts already billed"
: "Rendiconto ore già fatturati"

, "My Timesheets today"
: "La mia schede attività di oggi"

, "My Timesheets this week"
: "La mia scheda attività di questa settimana"

, "My Timesheets last week"
: "La mia scheda attività della scorsa settimana"

, "My Timesheets this month"
: "La mia scheda attività di questo mese"

, "My Timesheets last month"
: "La mia scheda attività dello scorso mese"

, "Manage timeaccounts"
: "Gestisci rendiconto ore"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Aggiungere, modificare ed eliminare i rendiconto ore (include tutte i permessi della scheda attività)"

, "Add timeaccounts"
: "Aggiungi rendiconto ore"

, "Manage shared timeaccount favorites"
: "Gestisci i rendiconto ore condivisi preferiti"

, "Create or update shared timeaccount favorites"
: "Crea o aggiorna i rendiconto ore condivisi preferiti"

, "Manage shared timesheet favorites"
: "gestisci le schede attività condivise preferite"

, "Create or update shared timesheet favorites"
: "Crea o aggiorna le schede attività condivise preferite"






, "Timesheet"
: "Tabella del tempo"

, "Timeaccount"
: ""

, "Time Account"
: "Account di Tempo"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
